# Security Guide

We take security seriously at EasyPost. If you find a security issue or vulnerability in our open source projects, please abide by the following guidelines:

- Please read our [Responsible Disclosure Policy](https://www.easypost.com/privacy#disclosure-policy).
- Do not open an issue on GitHub about the security vulnerability. Doing so draws attention to the issue and exposes it to the public.
- Send an email to `security-abuse@easypost.com` including as many details as possible.
